@@ -1160,12 +1160,21 @@ class Client(commandServer, encrypt, Desktop):
         unixDn = self.getInfoService("unix", "dn")
         bindDn = self.getInfoService("unix", "bind_dn")
         bindPw = self.getInfoService("unix", "bind_pw")
+        sambaHost = self.getInfoService("samba", "host")
         # check info from server
         if not (servDn and unixDn and bindDn and bindPw):
             raise ClientError(_("Info not found on the server") + _(": ") +
                               _(
                                   "services DN or unix DN or bind DN or bind password"))
         self.clVars.Set("os_remote_auth", domain)
+        try:
+            self.getDomainPassword(sambaHost)
+        except ClientError:
+            self.printWARNING(
+                _("Failed to authorize on %s") % sambaHost)
+            self.printWARNING(
+                _("Wrong value of variable sr_samba_host in %s") %
+                "/var/calculate/remote/calculate.env")
         return True
 
     def applyClientTemplates(self, hostAuth=""):
