@@ -20,6 +20,7 @@ from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.utils.files import FilesError
 from calculate.desktop.desktop import DesktopError
+from calculate.lib.utils.samba import SambaError
 from calculate.client.client import ClientError
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.mount import isMount
@@ -34,7 +35,8 @@ class ClClientSyncLoginAction(Action):
     Синхронизировать локальный профиль с удаленным, подключить удаленные
     ресурсы пользователя
     """
-    native_error = (FilesError, ClientError, DesktopError, TemplatesError)
+    native_error = (FilesError, ClientError, DesktopError, TemplatesError,
+                    SambaError)
 
     successMessage = None
     failedMessage = None
